AliceCore class

This class not exported outside package. It contains core logic for alice inspector.

Constructors

AliceCore({GlobalKey<NavigatorState>? navigatorKey})
factory

Properties

callsSubject → BehaviorSubject<List<AliceHttpCall>>
Rx subject which contains all intercepted http calls
final
context → BuildContext?
Get context from navigator key. Used to open inspector route.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasLogsStream → Stream<bool>
no setter
limitLogs ↔ int
getter/setter pair
logs → List<String>
no setter
logsStream → Stream<List<String>>
no setter
logsSubject → BehaviorSubject<List<String>>
final
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCall(AliceHttpCall call) → void
Add alice http call to calls subject
addError(AliceHttpError error, int requestId) → void
Add error to exisng alice http call
addHttpCall(AliceHttpCall aliceHttpCall) → void
Add alice http call to calls subject
addResponse(AliceHttpResponse response, int requestId) → void
Add response to existing alice http call
clear() → void
clearCalls() → void
clearLogs() → void
clears() → void
Remove all calls from calls subject
dispose() → void
Dispose subjects
getDioInterceptor() → AliceDioInterceptor
Get Dio interceptor which should be applied to Dio instance.
log(String message, {Color color = Colors.white}) → void
Opens Http calls inspector. This will navigate user to the new fullscreen page where all listened http calls can be viewed.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
push<T extends Object?>(Widget builder(BuildContext)) → Future<T?>
setNavigatorKey(GlobalKey<NavigatorState> navigatorKey) → void
Set custom navigation key. This will help if there's route library.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

inst → AliceCore
final