ExpandableFab class

Inheritance
Annotations

Constructors

ExpandableFab({Key? key, bool? initialOpen, required double distance, required List<Widget> children, required Widget bigButton, Duration animationDuration = const Duration(milliseconds: 250), Curve curve = Curves.fastOutSlowIn, Curve reverseCurve = Curves.easeOutQuad, bool enableHapticFeedback = true, bool expandTowardsLeft = true, bool expandDownwards = false, ValueChanged<bool>? onOpenChanged, double fabSize = 48.0})
const

Properties

animationDuration → Duration
final
bigButton → Widget
final
children → List<Widget>
final
curve → Curve
final
distance → double
final
enableHapticFeedback → bool
final
expandDownwards → bool
final
expandTowardsLeft → bool
final
fabSize → double
final
hashCode → int
The hash code for this object.
no setterinherited
initialOpen → bool?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onOpenChanged → ValueChanged<bool>?
final
reverseCurve → Curve
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<ExpandableFab>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited