AliceHttpCall class

Constructors

AliceHttpCall(int id)

Properties

client ↔ String
getter/setter pair
duration ↔ int
getter/setter pair
endpoint ↔ String
getter/setter pair
error ↔ AliceHttpError?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
loading ↔ bool
getter/setter pair
method ↔ String
getter/setter pair
request ↔ AliceHttpRequest?
getter/setter pair
response ↔ AliceHttpResponse?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secure ↔ bool
getter/setter pair
server ↔ String
getter/setter pair
uri ↔ String
getter/setter pair

Methods

getCurlCommand() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setResponse(AliceHttpResponse response) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited