AliceColors class

Semantic color palette for Alice HTTP Inspector.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

statusBadgeBg(Color color) → Color
Returns subtle translucent background for status badges (like Chrome DevTools)

Constants

background → const Color
card → const Color
darkConsoleBg → const Color
divider → const Color
error → const Color
green → const Color
grey → const Color
info → const Color
lightRed → const Color
orange → const Color
primary → const Color
primaryDark → const Color
primaryLight → const Color
red → const Color
success → const Color
surface → const Color
surfaceDark → const Color
textLight → const Color
textLightSecondary → const Color
textPrimary → const Color
textSecondary → const Color
warning → const Color