AliceStyles class

Typography definitions for Alice HTTP Inspector.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

body → const TextStyle
bodyBold → const TextStyle
bodyLarge → const TextStyle
caption → const TextStyle
captionBold → const TextStyle
mono → const TextStyle
monoBold → const TextStyle
titleLarge → const TextStyle
titleMedium → const TextStyle