AliceStatsThresholds class

Thresholds for warning, high, and urgent levels for slowest latency and frequent calls.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getErrorSeverity(int errorCount) → AliceSeverity
Evaluates severity based on endpoint error count.
getFrequencySeverity(int count) → AliceSeverity
Evaluates severity based on endpoint call frequency.
getLatencySeverity(int durationMs) → AliceSeverity
Evaluates severity based on call duration in milliseconds.

Constants

errorHighCount → const int
errorUrgentCount → const int
errorWarningCount → const int
frequentHighCount → const int
frequentUrgentCount → const int
frequentWarningCount → const int
latencyHighMs → const int
latencyUrgentMs → const int
latencyWarningMs → const int