AliceHttpCall class

Available extensions

Constructors

AliceHttpCall(int id)

Properties

client ↔ String
getter/setter pair
duration ↔ int
getter/setter pair
endpoint ↔ String
getter/setter pair
error ↔ AliceHttpError?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
loading ↔ bool
getter/setter pair
method ↔ String
getter/setter pair
request ↔ AliceHttpRequest?
getter/setter pair
response ↔ AliceHttpResponse?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secure ↔ bool
getter/setter pair
server ↔ String
getter/setter pair
statusText → String

Available on AliceHttpCall, provided by the AliceHttpCallUiExtension extension

Returns a concise status code string (e.g. 200, ERR, ???).
no setter
uri ↔ String
getter/setter pair

Methods

getCurlCommand() → String
getEndpointTextColor(BuildContext context) → Color

Available on AliceHttpCall, provided by the AliceHttpCallUiExtension extension

Returns text color for the endpoint text depending on loading status.
getStatusColor(BuildContext context) → Color

Available on AliceHttpCall, provided by the AliceHttpCallUiExtension extension

Returns text color based on the HTTP response status code.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setResponse(AliceHttpResponse response) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited